==> savane-1.0.3.1.tar.gz: savane/frontend/php/include/database.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: database.php,v 1.10 2004/06/29 09:49:31 yeupou Exp $
#  Copyright 1999-2000 (c) The SourceForge Crew
#            2004      (c) Elfyn McBratney <elfyn--at--emcb.co.uk>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

function db_connect() 
{
  global $sys_dbhost,$sys_dbuser,$sys_dbpasswd,$conn;

  # If persistant MySQL links are enabled, try and open a
  # persistant link.
  $mysql_persistant_links = ini_get('mysql.allow_persistent');
  if (strtolower($mysql_persistant_links) == 'on' || $mysql_persistant_links == '1' ) {
    $conn = mysql_pconnect($sys_dbhost,$sys_dbuser,$sys_dbpasswd);
  }

  # If $conn is not a valid resource, try and open a normal
  #x (non persistant) link.
  if (!is_resource($conn)) {
    $conn = mysql_connect($sys_dbhost,$sys_dbuser,$sys_dbpasswd);
  }
}

function db_query($qstring,$print=0) 
{

  #	global $QUERY_COUNT;
  #	$QUERY_COUNT++;
  if ($print) print "<br>Query is: $qstring<br>";
  #	if ($GLOBALS[IS_DEBUG]) $GLOBALS[G_DEBUGQUERY] .= $qstring . "<BR>\n";
  global $sys_dbname;
  $GLOBALS['db_qhandle'] = @mysql($sys_dbname,$qstring);
  return $GLOBALS['db_qhandle'];
}

function db_numrows($qhandle) 
{
  # return only if qhandle exists, otherwise 0
  if ($qhandle) {
    return @mysql_numrows($qhandle);
  } else {
    return 0;
  }
}

function db_free_result($qhandle) 
{
  return @mysql_free_result($qhandle);
}

function db_result($qhandle,$row,$field) 
{
  return @mysql_result($qhandle,$row,$field);
}

function db_numfields($lhandle) 
{
  return @mysql_numfields($lhandle);
}

function db_fieldname($lhandle,$fnumber) 
{
  return @mysql_fieldname($lhandle,$fnumber);
}

function db_affected_rows($qhandle) 
{
  return @mysql_affected_rows();
}
	
function db_fetch_array($qhandle = 0) 
{

  if ($qhandle) {
    return @mysql_fetch_array($qhandle);
  } else {
    if ($GLOBALS['db_qhandle']) {
      return @mysql_fetch_array($GLOBALS['db_qhandle']);
    } else {
      return (array());
    }
  }
}
	
function db_insertid($qhandle) 
{

  return @mysql_insert_id();
}

function db_error() 
{
  return @mysql_error();
}

?>

==> savane-1.0.4.1.tar.gz: savane/frontend/php/include/database.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: database.php,v 1.12 2004/09/22 19:28:19 beu Exp $
#  Copyright 1999-2000 (c) The SourceForge Crew
#            2004      (c) Elfyn McBratney <elfyn--at--emcb.co.uk>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

function db_connect() 
{
  global $sys_dbhost,$sys_dbuser,$sys_dbpasswd,$conn;

  $conn = mysql_connect($sys_dbhost,$sys_dbuser,$sys_dbpasswd);
  if (!$conn) {
    die("Failed to connect to database.  Please contact server administratots.");
  }
}

function db_query($qstring,$print=0) 
{

  #	global $QUERY_COUNT;
  #	$QUERY_COUNT++;
  if ($print) print "<br />Query is: $qstring<br />";
  #	if ($GLOBALS[IS_DEBUG]) $GLOBALS[G_DEBUGQUERY] .= $qstring . "<BR>\n";
  global $sys_dbname;
  $GLOBALS['db_qhandle'] = @mysql($sys_dbname,$qstring);
  return $GLOBALS['db_qhandle'];
}

function db_numrows($qhandle) 
{
  # return only if qhandle exists, otherwise 0
  if ($qhandle) {
    return @mysql_numrows($qhandle);
  } else {
    return 0;
  }
}

function db_free_result($qhandle) 
{
  return @mysql_free_result($qhandle);
}

function db_result($qhandle,$row,$field) 
{
  return @mysql_result($qhandle,$row,$field);
}

function db_numfields($lhandle) 
{
  return @mysql_numfields($lhandle);
}

function db_fieldname($lhandle,$fnumber) 
{
  return @mysql_fieldname($lhandle,$fnumber);
}

function db_affected_rows($qhandle) 
{
  return @mysql_affected_rows();
}
	
function db_fetch_array($qhandle = 0) 
{

  if ($qhandle) {
    return @mysql_fetch_array($qhandle);
  } else {
    if ($GLOBALS['db_qhandle']) {
      return @mysql_fetch_array($GLOBALS['db_qhandle']);
    } else {
      return (array());
    }
  }
}
	
function db_insertid($qhandle) 
{

  return @mysql_insert_id();
}

function db_error() 
{
  return @mysql_error();
}

?>
